/*
Modified by Kenichi KAKIZAKI
2015/12/27
2015/12/20
2015/11/03
2015/05/08
*/

#ifndef CLCD_ST7032_h
#define CLCD_ST7032_h

//#include <inttypes.h>
#include "Print.h"

#define	CLCD_ST7032_ADDR	0x3e

#if defined(__AVR__)
#define	__POWER5V__
#endif


#if defined(__POWER5V__)
// 5V
#define	CLCD_ST7032_CONTRAST	12
#else
// 3V3
#define	CLCD_ST7032_CONTRAST	32
#endif

// commands
#define LCD_CLEARDISPLAY 0x01
#define LCD_RETURNHOME 0x02
#define LCD_ENTRYMODESET 0x04
#define LCD_DISPLAYCONTROL 0x08
#define LCD_CURSORSHIFT 0x10
#define LCD_FUNCTIONSET 0x30
#define LCD_SETCGRAMADDR 0x40
#define LCD_SETDDRAMADDR 0x80


#define LCD_OSCFREQ 0x10
#define LCD_POWERCONTRAST 0x50
#define LCD_FOLLOWER 0x60
#define LCD_CONTRAST 0x70

// flags for display entry mode
#define LCD_ENTRYRIGHT 0x00
#define LCD_ENTRYLEFT 0x02
#define LCD_ENTRYSHIFTINCREMENT 0x01
#define LCD_ENTRYSHIFTDECREMENT 0x00

// flags for display on/off control
#define LCD_DISPLAYON 0x04
#define LCD_DISPLAYOFF 0x00
#define LCD_CURSORON 0x02
#define LCD_CURSOROFF 0x00
#define LCD_BLINKON 0x01
#define LCD_BLINKOFF 0x00

// flags for display/cursor shift
#define LCD_DISPLAYMOVE 0x08
#define LCD_CURSORMOVE 0x00
#define LCD_MOVERIGHT 0x04
#define LCD_MOVELEFT 0x00

// flags for function set
#define LCD_2LINE 0x08
#define LCD_1LINE 0x00
#define LCD_5x10DOTS 0x04
#define LCD_5x8DOTS 0x00
#define LCD_EIS 0x01

// flags for booster set
#define LCD_BOOSTER 0x04


class CLCD_ST7032 : public Print {
public:
#if defined(ARDUINO_ARCH_ESP8266)
  CLCD_ST7032(uint8_t sda, uint8_t scl);
  CLCD_ST7032();

  void init(uint8_t scl, uint8_t sda);
#else
  CLCD_ST7032();

  void init();
#endif
  void begin(uint8_t cols, uint8_t rows, uint8_t charsize = LCD_5x8DOTS);

  void clear();
  void home();

  void noDisplay();
  void display();
  void noBlink();
  void blink();
  void noCursor();
  void cursor();
  void scrollDisplayLeft();
  void scrollDisplayRight();
  void leftToRight();
  void rightToLeft();
  void autoscroll();
  void noAutoscroll();
  void setContrast(uint8_t);
  uint8_t getContrast();

  void setRowOffsets(int row1, int row2, int row3, int row4);
  void createChar(uint8_t, uint8_t[]);
  void setCursor(uint8_t, uint8_t); 
  virtual size_t write(uint8_t);
  void command(uint8_t);
  
  using Print::write;

private:
  void send(uint8_t, uint8_t);

  uint8_t _addr ;
#if defined(ARDUINO_ARCH_ESP8266)
  uint8_t _scl ;
  uint8_t _sda ;
#endif

  uint8_t _displayfunction;
  uint8_t _displaycontrol;
  uint8_t _displaymode;

  uint8_t _initialized;

  uint8_t _numlines;
  uint8_t _row_offsets[4];

  uint8_t _contrast;
};

#endif
